@@ -1,5 +1,3 @@
-#!/usr/bin/perl -w
-
 #############################################################################
 # Math/String/Sequence.pm -- defines a sequence or range of strings.
 #
@@ -15,15 +13,14 @@
 
 package Math::String::Sequence;
 use vars qw($VERSION);
-$VERSION = 1.03;    # Current version of this package
-require  5.005;     # requires this Perl version or later
+$VERSION = '1.04';	# Current version of this package
+require  5.005;		# requires this Perl version or later
 
 use Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(sequence);
-#@EXPORT = qw( );
 
-use Math::BigInt;
+use Math::BigInt lib => 'GMP';
 use Math::String;
 use Math::String::Charset;
 
